excalibur
=========

A tool to manage plugins.

For more information have a look at sphinx's documentation `here <http://unistra.github.io/excalibur/>`_

.. image:: https://secure.travis-ci.org/unistra/excalibur.png?branch=master
    :target: https://travis-ci.org/unistra/excalibur
    :alt: Build

.. image:: http://coveralls.io/repos/unistra/excalibur/badge.png?branch=master
    :target: http://coveralls.io/r/unistra/excalibur?branch=master
    :alt: Coverage

.. image:: https://img.shields.io/pypi/v/excalibur.svg
    :target: https://pypi.python.org/pypi/excalibur
    :alt: Version

.. image:: https://img.shields.io/pypi/pyversions/excalibur.svg
    :target: https://pypi.python.org/pypi/excalibur
    :alt: Python Version

.. image:: https://img.shields.io/pypi/status/excalibur.svg
    :target: https://pypi.python.org/pypi/excalibur
    :alt: Status

.. image:: https://img.shields.io/pypi/l/excalibur.svg
    :target: https://docs.python.org/2/license.html
    :alt: Licence

.. image:: https://img.shields.io/pypi/dm/excalibur.svg
    :target: https://pypi.python.org/pypi/excalibur
    :alt: Download

.. image:: https://landscape.io/github/unistra/excalibur/master/landscape.svg?style=flat
  :target: https://landscape.io/github/unistra/excalibur/master
  :alt: Code Health
